"""
Lump 42 - Cubemaps
==================

This lump contains an array of :any:`dcubemapsample_t`.
"""

from __future__ import division
from __future__ import absolute_import
from __future__ import print_function
from __future__ import unicode_literals
from future import standard_library
standard_library.install_aliases()

from construct import *  # NOQA: #402
from valvebsp.structs.common import *  # NOQA #402

dcubemapsample_t = Struct(
    'origin' / Int32sl[3],
    'size' / Int32sl
)


@lump_array
@lump_version(0)
def lump_42(header, profile=None):
    return dcubemapsample_t
