from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

from future import standard_library
standard_library.install_aliases()

TEAMFORTRESS2 = 'TF2'  #:
PORTAL2 = 'P2'  #:
LEFT4DEAD2 = 'L4D2'  #:
ALIENSWARM = 'AS'  #:
ZENOCLASH = 'ZC'  #:
VINDICTUS = 'VIN'  #:
CONTAGION = 'CON'  #:
TITANFALL = 'TIT'  #:
THESHIP = 'SHIP'  #:

#: :obj:`dict` :
#: Utility dict listing available profiles.
PROFILES = {
    'TEAMFORTRESS2': TEAMFORTRESS2,
    'PORTAL2': PORTAL2,
    'LEFT4DEAD2': LEFT4DEAD2,
    'ALIENSWARM': ALIENSWARM,
    'ZENOCLASH': ZENOCLASH,
    'VINDICTUS': VINDICTUS,
    'CONTAGION': CONTAGION,
    'TITANFALL': TITANFALL,
    'THESHIP': THESHIP,
}
